@@ -4,7 +4,7 @@ import numpy as np
 # from tian_STMB_new import STMB
 from rpi_featureSelection_python_tools.stmbplus_tools import *
 
-class STMBFeatureSelector():
+class STMBPlusFeatureSelector():
     """
     This class implements a feature selection method:
 
